==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.publish.basic/src/com/openexchange/publish/osgi/DiscovererActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.osgi;

import java.util.Hashtable;
import org.osgi.framework.Constants;
import com.openexchange.database.provider.DBProvider;
import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
import com.openexchange.groupware.delete.DeleteListener;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.publish.PublicationTargetDiscoveryService;
import com.openexchange.publish.database.PublicationUserDeleteListener;
import com.openexchange.publish.helpers.AbstractPublicationService;
import com.openexchange.publish.helpers.FolderSecurityStrategy;
import com.openexchange.publish.sql.PublicationSQLStorage;
import com.openexchange.publish.tools.CompositePublicationTargetDiscoveryService;
import com.openexchange.userconf.UserConfigurationService;

/**
 * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
 */
public class DiscovererActivator extends HousekeepingActivator {

    private OSGiPublicationTargetCollector pubServiceCollector;

    private OSGiPublicationTargetDiscovererCollector discovererCollector;

    @Override
    public void startBundle() throws Exception {

        pubServiceCollector = new OSGiPublicationTargetCollector(context);
        discovererCollector = new OSGiPublicationTargetDiscovererCollector(context);

        final CompositePublicationTargetDiscoveryService compositeDiscovererCollector = new CompositePublicationTargetDiscoveryService();
        compositeDiscovererCollector.addDiscoveryService(pubServiceCollector);
        compositeDiscovererCollector.addDiscoveryService(discovererCollector);

        discovererCollector.ignore(compositeDiscovererCollector);

        final Hashtable<String, Object> discoveryDict = new Hashtable<String, Object>(1);
        discoveryDict.put(Constants.SERVICE_RANKING, Integer.valueOf(256));

        registerService(PublicationTargetDiscoveryService.class, compositeDiscovererCollector, discoveryDict);

        final DBProvider provider = getService(DBProvider.class);
        final GenericConfigurationStorageService confStorage = getService(GenericConfigurationStorageService.class);

        AbstractPublicationService.setDefaultStorage( new PublicationSQLStorage(provider, confStorage, compositeDiscovererCollector) );
        AbstractPublicationService.FOLDER_ADMIN_ONLY = new FolderSecurityStrategy(getService(UserConfigurationService.class));

        final PublicationUserDeleteListener listener = new PublicationUserDeleteListener();
        listener.setDiscoveryService(compositeDiscovererCollector);
        listener.setGenConfStorage(confStorage);

        registerService(DeleteListener.class, listener, null);
    }

    @Override
    public void stopBundle() throws Exception {
        unregisterServices();
        pubServiceCollector.close();
        pubServiceCollector = null;
        discovererCollector.close();
        discovererCollector = null;
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { DBProvider.class, GenericConfigurationStorageService.class, UserConfigurationService.class };
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.publish.basic/src/com/openexchange/publish/osgi/DiscovererActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.osgi;

import java.util.Hashtable;
import org.osgi.framework.Constants;
import com.openexchange.database.provider.DBProvider;
import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
import com.openexchange.groupware.delete.DeleteListener;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.publish.PublicationTargetDiscoveryService;
import com.openexchange.publish.database.PublicationUserDeleteListener;
import com.openexchange.publish.helpers.AbstractPublicationService;
import com.openexchange.publish.helpers.FolderSecurityStrategy;
import com.openexchange.publish.sql.PublicationSQLStorage;
import com.openexchange.publish.tools.CompositePublicationTargetDiscoveryService;
import com.openexchange.userconf.UserConfigurationService;

/**
 * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
 */
public class DiscovererActivator extends HousekeepingActivator {

    private volatile OSGiPublicationTargetCollector pubServiceCollector;

    private volatile OSGiPublicationTargetDiscovererCollector discovererCollector;

    @Override
    public void startBundle() throws Exception {

        final OSGiPublicationTargetCollector pubServiceCollector = new OSGiPublicationTargetCollector(context);
        this.pubServiceCollector = pubServiceCollector;
        final OSGiPublicationTargetDiscovererCollector discovererCollector = new OSGiPublicationTargetDiscovererCollector(context);
        this.discovererCollector = discovererCollector;

        final CompositePublicationTargetDiscoveryService compositeDiscovererCollector = new CompositePublicationTargetDiscoveryService();
        compositeDiscovererCollector.addDiscoveryService(pubServiceCollector);
        compositeDiscovererCollector.addDiscoveryService(discovererCollector);

        discovererCollector.ignore(compositeDiscovererCollector);

        final Hashtable<String, Object> discoveryDict = new Hashtable<String, Object>(1);
        discoveryDict.put(Constants.SERVICE_RANKING, Integer.valueOf(256));

        registerService(PublicationTargetDiscoveryService.class, compositeDiscovererCollector, discoveryDict);

        final DBProvider provider = getService(DBProvider.class);
        final GenericConfigurationStorageService confStorage = getService(GenericConfigurationStorageService.class);

        AbstractPublicationService.setDefaultStorage( new PublicationSQLStorage(provider, confStorage, compositeDiscovererCollector) );
        AbstractPublicationService.FOLDER_ADMIN_ONLY = new FolderSecurityStrategy(getService(UserConfigurationService.class));

        final PublicationUserDeleteListener listener = new PublicationUserDeleteListener();
        listener.setDiscoveryService(compositeDiscovererCollector);
        listener.setGenConfStorage(confStorage);

        registerService(DeleteListener.class, listener, null);
    }

    @Override
    public void stopBundle() throws Exception {
        cleanUp();
        final OSGiPublicationTargetCollector pubServiceCollector = this.pubServiceCollector;
        if (null != pubServiceCollector) {
            pubServiceCollector.close();
            this.pubServiceCollector = null;
        }
        final OSGiPublicationTargetDiscovererCollector discovererCollector = this.discovererCollector;
        if (null != discovererCollector) {
            discovererCollector.close();
            this.discovererCollector = null;
        }
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { DBProvider.class, GenericConfigurationStorageService.class, UserConfigurationService.class };
    }

}
